==> MRAConnector-0.84.tar.bz2: MRAConnector-0.84/core/Smdn.Net.Pop3.Client/Test/Smdn.Net.Pop3.Client/PopClientProfile.cs <==
using System;
using System.Net;
using NUnit.Framework;

namespace Smdn.Net.Pop3.Client {
  [TestFixture]
  public class PopClientProfileTests {
    [Test]
    public void TestClone()
    {
      var original = new PopClientProfile(new Uri("pop://user@localhost/"));

      original.Timeout = 1;
      original.ReceiveTimeout = 2;
      original.SendTimeout = 3;
      original.UseTlsIfAvailable = false;
      original.UsingSaslMechanisms = new string[] {"X-SASL-EXT"};
      original.AllowInsecureLogin = true;

      var cloned = original.Clone();

      Assert.AreNotSame(cloned, original);
      Assert.AreNotSame(original.Authority, cloned.Authority);
      Assert.AreEqual(original.Authority, cloned.Authority);
      Assert.AreEqual(1, cloned.Timeout);
      Assert.AreEqual(2, cloned.ReceiveTimeout);
      Assert.AreEqual(3, cloned.SendTimeout);
      Assert.IsFalse(cloned.UseTlsIfAvailable);
      Assert.AreNotSame(original.UsingSaslMechanisms, cloned.UsingSaslMechanisms);
      CollectionAssert.AreEqual(original.UsingSaslMechanisms, cloned.UsingSaslMechanisms);
      Assert.IsTrue(cloned.AllowInsecureLogin);
    }

    [Test]
    public void TestCloneUsingSaslMechanismsNull()
    {
      var original = new PopClientProfile(new Uri("pop://user@localhost/"));

      original.UsingSaslMechanisms = null;

      var cloned = original.Clone();

      Assert.AreNotSame(cloned, original);
      Assert.AreNotSame(original.Authority, cloned.Authority);
      Assert.AreEqual(original.Authority, cloned.Authority);
      Assert.IsNull(cloned.UsingSaslMechanisms);
    }

    [Test]
    public void TestSerializeBinary()
    {
      var original = new PopClientProfile(new Uri("pop://user@localhost/"));

      original.Timeout = 1;
      original.ReceiveTimeout = 2;
      original.SendTimeout = 3;
      original.UseTlsIfAvailable = false;
      original.UsingSaslMechanisms = new string[] {"X-SASL-EXT"};
      original.AllowInsecureLogin = true;

      Smdn.Net.TestUtils.SerializeBinary(original, delegate(PopClientProfile deserialized) {
        Assert.AreEqual(original.Authority, deserialized.Authority);
        Assert.AreEqual(1, deserialized.Timeout);
        Assert.AreEqual(2, deserialized.ReceiveTimeout);
        Assert.AreEqual(3, deserialized.SendTimeout);
        Assert.IsFalse(deserialized.UseTlsIfAvailable);
        Assert.AreNotSame(original.UsingSaslMechanisms, deserialized.UsingSaslMechanisms);
        CollectionAssert.AreEqual(original.UsingSaslMechanisms, deserialized.UsingSaslMechanisms);
        Assert.IsTrue(deserialized.AllowInsecureLogin);
      });
    }
  }
}

==> MRAConnector-1.12.tar.bz2: MRAConnector-1.12/core/Smdn.Net.Pop3.Client/Test/Smdn.Net.Pop3.Client/PopClientProfile.cs <==
using System;
using System.Net;
using NUnit.Framework;

namespace Smdn.Net.Pop3.Client {
  [TestFixture]
  public class PopClientProfileTests {
    [Test]
    public void TestClone()
    {
      var original = new PopClientProfile(new Uri("pop://user@localhost/"));

      original.Timeout = 1;
      original.ReceiveTimeout = 2;
      original.SendTimeout = 3;
      original.UseTlsIfAvailable = false;
      original.UsingSaslMechanisms = new string[] {"X-SASL-EXT"};
      original.AllowInsecureLogin = true;
      original.AllowStandardLogin = false;
      original.AllowApopLogin = false;

      var cloned = original.Clone();

      Assert.AreNotSame(cloned, original);
      Assert.AreNotSame(original.Authority, cloned.Authority);
      Assert.AreEqual(original.Authority.AbsoluteUri, cloned.Authority.AbsoluteUri);
      Assert.AreEqual(1, cloned.Timeout);
      Assert.AreEqual(2, cloned.ReceiveTimeout);
      Assert.AreEqual(3, cloned.SendTimeout);
      Assert.IsFalse(cloned.UseTlsIfAvailable);
      Assert.AreNotSame(original.UsingSaslMechanisms, cloned.UsingSaslMechanisms);
      CollectionAssert.AreEqual(original.UsingSaslMechanisms, cloned.UsingSaslMechanisms);
      Assert.IsTrue(cloned.AllowInsecureLogin);
      Assert.IsFalse(cloned.AllowStandardLogin);
      Assert.IsFalse(cloned.AllowApopLogin);
    }

    [Test]
    public void TestCloneUsingSaslMechanismsNull()
    {
      var original = new PopClientProfile(new Uri("pop://user@localhost/"));

      original.UsingSaslMechanisms = null;

      var cloned = original.Clone();

      Assert.AreNotSame(cloned, original);
      Assert.AreNotSame(original.Authority, cloned.Authority);
      Assert.AreEqual(original.Authority.AbsoluteUri, cloned.Authority.AbsoluteUri);
      Assert.IsNull(cloned.UsingSaslMechanisms);
    }

    [Test]
    public void TestSerializeBinary()
    {
      var original = new PopClientProfile(new Uri("pop://user@localhost/"));

      original.Timeout = 1;
      original.ReceiveTimeout = 2;
      original.SendTimeout = 3;
      original.UseTlsIfAvailable = false;
      original.UsingSaslMechanisms = new string[] {"X-SASL-EXT"};
      original.AllowInsecureLogin = true;
      original.AllowStandardLogin = false;
      original.AllowApopLogin = false;

      Smdn.Net.TestUtils.SerializeBinary(original, delegate(PopClientProfile deserialized) {
        Assert.AreEqual(original.Authority.AbsoluteUri, deserialized.Authority.AbsoluteUri);
        Assert.AreEqual(1, deserialized.Timeout);
        Assert.AreEqual(2, deserialized.ReceiveTimeout);
        Assert.AreEqual(3, deserialized.SendTimeout);
        Assert.IsFalse(deserialized.UseTlsIfAvailable);
        Assert.AreNotSame(original.UsingSaslMechanisms, deserialized.UsingSaslMechanisms);
        CollectionAssert.AreEqual(original.UsingSaslMechanisms, deserialized.UsingSaslMechanisms);
        Assert.IsTrue(deserialized.AllowInsecureLogin);
        Assert.IsFalse(deserialized.AllowStandardLogin);
        Assert.IsFalse(deserialized.AllowApopLogin);
      });
    }
  }
}
